## Arches Controlled Lists 1.1.0 Release Notes

### Dependency changes:
```
Python:
    Upgraded:
        arches: >=8.0.1 -> >=8.1.0
        arches-component-lab: ==0.0.1a3 -> >=0.0.1a7
    Added:
        None

    Removed:
        None


JavaScript:
    Upgraded:
        arches: dev/8.0.x -> dev/8.1.x

    Added:
        None

    Removed:
        None
```

### Major enhancements

- Adds a utility to modify the base url for controlled list items. [#210](https://github.com/archesproject/arches-controlled-lists/pull/210)
- Adds RDF methods (`to_rdf`, `from_rdf`, `get_rdf_uri`, `accepts_rdf_uri`, `ignore_keys`) to the reference datatype, enabling RDF serialization and deserialization of controlled list values. [#230](https://github.com/archesproject/arches-controlled-lists/pull/230)
- Allows importing controlled lists from directories and exporting multiple lists at once. [#216](https://github.com/archesproject/arches-controlled-lists/pull/216)
- Makes the reference-select widget filterable. [#228](https://github.com/archesproject/arches-controlled-lists/pull/228)
- Adds support for free-form search of reference datatypes. [#232](https://github.com/archesproject/arches-controlled-lists/pull/232)

### Additional highlights

- Symbolically differentiates between guide and indexable items. [#185](https://github.com/archesproject/arches-controlled-lists/pull/185)
- Provides better options for the export file name. [#198](https://github.com/archesproject/arches-controlled-lists/pull/198)
- Improves performance by minimizing node queries using a cache, and improves validation to return all errors rather than stopping at the first.
- Fixed a bug where default values were not populated in the vue widget. [#223](https://github.com/archesproject/arches-controlled-lists/issues/223)

### Upgrading Arches Controlled Lists

1. Upgrade python package
    ```
    pip install --upgrade arches-controlled-lists==1.1.0
    ```

1. Update webpack build
    ```
    npm run build_development
    python manage.py collectstatic
    ```

1. If you are running Arches on Apache, restart your server:
    ```
    sudo service apache2 reload
    ```
